==> jc-1.4.0.tar.gz: javax/swing/undo/CannotUndoException.h <==
// public class javax.swing.undo.CannotUndoException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 41575ca8695ac2f0 javax_swing_undo_CannotUndoException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_javax_swing_undo_CannotUndoException_H_
#define _JC_javax_swing_undo_CannotUndoException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_undo_CannotUndoException$sub_refs	_jc_javax_swing_undo_CannotUndoException$sub_refs;
typedef struct _jc_javax_swing_undo_CannotUndoException$sub_nonrefs	_jc_javax_swing_undo_CannotUndoException$sub_nonrefs;
typedef struct _jc_javax_swing_undo_CannotUndoException$refs	_jc_javax_swing_undo_CannotUndoException$refs;
typedef struct _jc_javax_swing_undo_CannotUndoException$nonrefs	_jc_javax_swing_undo_CannotUndoException$nonrefs;
typedef struct _jc_javax_swing_undo_CannotUndoException$object	_jc_javax_swing_undo_CannotUndoException$object;

typedef const struct _jc_javax_swing_undo_CannotUndoException$vmethods	_jc_javax_swing_undo_CannotUndoException$vmethods;
typedef const struct _jc_javax_swing_undo_CannotUndoException$vtable	_jc_javax_swing_undo_CannotUndoException$vtable;
typedef const struct _jc_javax_swing_undo_CannotUndoException$vtype	_jc_javax_swing_undo_CannotUndoException$vtype;

// Constructors
extern void _jc_javax_swing_undo_CannotUndoException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_undo_CannotUndoException$object *);

// Virtual methods structure
struct _jc_javax_swing_undo_CannotUndoException$vmethods {
};

// Vtable
struct _jc_javax_swing_undo_CannotUndoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_javax_swing_undo_CannotUndoException$vmethods	javax_swing_undo_CannotUndoException;
};

// Vtype
struct _jc_javax_swing_undo_CannotUndoException$vtype {
	_jc_type			type;
	_jc_javax_swing_undo_CannotUndoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotUndoException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_undo_CannotUndoException$refs {
    _jc_javax_swing_undo_CannotUndoException$sub_refs	javax_swing_undo_CannotUndoException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotUndoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_undo_CannotUndoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_javax_swing_undo_CannotUndoException$sub_nonrefs	javax_swing_undo_CannotUndoException;
};

// Object instance structure
struct _jc_javax_swing_undo_CannotUndoException$object {
	_jc_javax_swing_undo_CannotUndoException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_undo_CannotUndoException$vtype	*vtype;
	_jc_javax_swing_undo_CannotUndoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_undo_CannotUndoException$vtype _jc_javax_swing_undo_CannotUndoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_undo_CannotUndoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_undo_CannotUndoException$class_object;

#endif	/* _JC_javax_swing_undo_CannotUndoException_H_ */

==> jc-1.4.6.tar.gz: javax/swing/undo/CannotUndoException.h <==
// public class javax.swing.undo.CannotUndoException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 41575ca8695ac2f0 javax_swing_undo_CannotUndoException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_javax_swing_undo_CannotUndoException_H_
#define _JC_javax_swing_undo_CannotUndoException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_undo_CannotUndoException$sub_refs	_jc_javax_swing_undo_CannotUndoException$sub_refs;
typedef struct _jc_javax_swing_undo_CannotUndoException$sub_nonrefs	_jc_javax_swing_undo_CannotUndoException$sub_nonrefs;
typedef struct _jc_javax_swing_undo_CannotUndoException$refs	_jc_javax_swing_undo_CannotUndoException$refs;
typedef struct _jc_javax_swing_undo_CannotUndoException$nonrefs	_jc_javax_swing_undo_CannotUndoException$nonrefs;
typedef struct _jc_javax_swing_undo_CannotUndoException$object	_jc_javax_swing_undo_CannotUndoException$object;

typedef const struct _jc_javax_swing_undo_CannotUndoException$vmethods	_jc_javax_swing_undo_CannotUndoException$vmethods;
typedef const struct _jc_javax_swing_undo_CannotUndoException$vtable	_jc_javax_swing_undo_CannotUndoException$vtable;
typedef const struct _jc_javax_swing_undo_CannotUndoException$vtype	_jc_javax_swing_undo_CannotUndoException$vtype;

// Constructors
extern void _jc_javax_swing_undo_CannotUndoException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_undo_CannotUndoException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_undo_CannotUndoException$vmethods {
};

// Vtable
struct _jc_javax_swing_undo_CannotUndoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_javax_swing_undo_CannotUndoException$vmethods	javax_swing_undo_CannotUndoException;
};

// Vtype
struct _jc_javax_swing_undo_CannotUndoException$vtype {
	_jc_type			type;
	_jc_javax_swing_undo_CannotUndoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotUndoException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_undo_CannotUndoException$refs {
    _jc_javax_swing_undo_CannotUndoException$sub_refs	javax_swing_undo_CannotUndoException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_undo_CannotUndoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_undo_CannotUndoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_javax_swing_undo_CannotUndoException$sub_nonrefs	javax_swing_undo_CannotUndoException;
};

// Object instance structure
struct _jc_javax_swing_undo_CannotUndoException$object {
	_jc_javax_swing_undo_CannotUndoException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_undo_CannotUndoException$vtype	*vtype;
	_jc_javax_swing_undo_CannotUndoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_undo_CannotUndoException$vtype _jc_javax_swing_undo_CannotUndoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_undo_CannotUndoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_undo_CannotUndoException$class_object;

#endif	/* _JC_javax_swing_undo_CannotUndoException_H_ */
